==> qdvdauthor_0.0.8a.orig.tar.gz: qdvdauthor-0.0.8a/qdvdauthor/xml_dvd.h <==
/////////////////
// Hey
////////////////
#ifndef XML_DVD_H
#define XML_DVD_H

// Here is the doc type for the QDVDAuthor application.
#define XML_DOCTYPE "QDVDAuthor"
#define DVD_PROJECT "QDVDProject"

#define THE_PROJECT_NAME "ProjectName"

// The following version number is used for the xml - ProjectFile
#define QDVDAUTHOR_VERSION		"XMLVersion"
#define QDVDAUTHOR_VERSION_NUMBER	"0.0.7"

// Here are the defines for qdvdauthor.
#define DVDAUTHOR                               "DVDAuthor"
#define DVDAUTHOR_PATH                          "DVDAuthorPath"
#define DVDAUTHOR_TEMP_PATH                     "TempPath"
#define DVDAUTHOR_PROJECT_PATH                  "ProjectPath"
#define DVDAUTHOR_CURRENT_PATH                  "CurrentPath"
#define DVDAUTHOR_MPEG_TOOLS_PATH               "MpegToolsPath"
#define DVDAUTHOR_ROOT_VMGM                     "MainVMGM"
#define DVDAUTHOR_ROOT_MENU                     "DVDMenu"
#define DVDAUTHOR_MENU                          "MenuVariables"
#define DVDAUTHOR_PREVIEW                       "PreviewVariables"

// Here are the defines for teh DVDMenu - Interface.
//#define DVD_MENU                                "DVDMenu"
#define MENU_NAME                               "MenuName"
#define MENU_SOUND                              "MenuSound"
#define MENU_MOVIE                              "MenuMovie"
#define MENU_BACKGROUND                         "MenuBackround"
#define MENU_HIGHLIGHTED_MASK                   "MenuHighlightedMask"
#define MENU_SELECTED_MASK                      "MenuSelectedMask"
#define MENU_MASK_COLORS                        "MaskColors"
#define MENU_RESIZE_ALGO                        "ResizeAlgo"
#define MENU_FORMAT                             "MenuFormat"
#define MENU_WIDTH                              "MenuWidth"
#define MENU_HEIGHT                             "MenuHeight"

// Here are the defines for the MenuObject derived classes ...
#define MENU_OBJECT                             "MenuObject"
//#define MENU_OBJECT_FRAME                       "FrameObject"
#define MENU_OBJECT_TEXT                        "TextObject"
#define MENU_OBJECT_IMAGE                       "ImageObject"
#define MENU_OBJECT_MOVIE                       "MovieObject"
#define MENU_OBJECT_BUTTON                      "ButtonObject"
#define MENU_OBJECT_COLLECTION                  "ObjectCollection"

// The MenuObject Variables ...
#define MENU_OBJECT_NAME                        "ObjectName"

// The FrameObject - class
#define FRAME_OBJECT                            "FrameObject"
#define FRAME_OBJECT_COLOR                      "Color"
#define FRAME_OBJECT_WIDTH                      "Width"
#define FRAME_OBJECT_STYLE                      "Style"
#define FRAME_OBJECT_JOIN                       "Join"

// The TextObject - class
#define TEXT_OBJECT                             "TextObject"
#define TEXT_OBJECT_TEXT                        "Text"
#define TEXT_OBJECT_TEXT_ALIGN                  "TextAlign"
#define TEXT_OBJECT_FONT                        "Font"
#define TEXT_OBJECT_BACKGROUND_COLOR            "BackgroundColor"
#define TEXT_OBJECT_FOREGROUND_COLOR            "ForegroundColor"

// The ImageObject - class
#define IMAGE_OBJECT                            "ImageObject"
#define IMAGE_OBJECT_FILE_NAME                  "FileName"

// The MovieObject - class
#define MOVIE_OBJECT                            "MovieObject"

// The ObjectCollection - class
#define OBJECT_COLLECTION                       "ObjectCollection"

#define BUTTON_OBJECT                           "ButtonObject"
#define BUTTON_OBJECT_NAME                      "ButtonName"
#define BUTTON_OBJECT_NORMAL                    "NormalState"
#define BUTTON_OBJECT_SELECTED                  "SelectedState"
#define BUTTON_OBJECT_HIGHLIGHTED               "HighlightedState"
#define BUTTON_OBJECT_ACTION                    "Action"
#define BUTTON_OBJECT_UP                        "Up"
#define BUTTON_OBJECT_DOWN                      "Down"
#define BUTTON_OBJECT_LEFT                      "Left"
#define BUTTON_OBJECT_RIGHT                     "Right"
#define BUTTON_OBJECT_SOURCE_ENTRY              "SourceEntry"

// The SourceFileEntry - class
#define SOURCE_OBJECT                           "SourceEntry"
#define SOURCE_OBJECT_DISPLAY_NAME              "DisplayName"
#define SOURCE_OBJECT_IS_SOUND_SOURCE           "SoundSource"
#define SOURCE_OBJECT_INFO                      "SourceInfo"
#define SOURCE_OBJECT_FILE_NAME                 "File"
#define SOURCE_OBJECT_CHAPTERS                  "Chapters"
#define SOURCE_OBJECT_SIZE                      "Size"
#define SOURCE_OBJECT_RESOLUTION                "Resolution"
#define SOURCE_OBJECT_FPS                       "FPS"
#define SOURCE_OBJECT_RATIO                     "Ratio"
#define SOURCE_OBJECT_LENGTH                    "Length"
#define SOURCE_OBJECT_FORMAT                    "Format"
#define SOURCE_OBJECT_STATUS                    "Status"
#define SOURCE_OBJECT_BITS                      "Bits"
#define SOURCE_OBJECT_SAMPLE                    "Sample"
#define SOURCE_OBJECT_BPS                       "BPS"


// The Modifier - class - variables :
#define MODIFIERS                               "Modifiers"
#define MODIFIERS_ROTATE                        "Rotate"
#define MODIFIERS_ZOOM                          "Zoom"
#define MODIFIERS_SCALEX                        "ScaleX"
#define MODIFIERS_SCALEY                        "ScaleY"
#define MODIFIERS_SHEARX                        "ShearX"
#define MODIFIERS_SHEARY                        "ShearY"
#define MODIFIERS_TRANSPARENCY                  "Transparency"

// The ImageManipulator - class
#define MANIPULATOR                             "Manipulator"
#define MANIPULATOR_FILE_NAME                   "FileName"
#define MANIPULATOR_SHOW_BACKGROUND             "ShowBackground"
#define MANIPULATOR_STARTX                      "StartX"
#define MANIPULATOR_STARTY                      "StartY"
#define MANIPULATOR_XRES                        "XRes"
#define MANIPULATOR_YRES                        "YRes"
#define MANIPULATOR_TRANSFORMATION_MODE	        "TransformationMode"
#define MANIPULATOR_ASPECT_RATIO                "AspectRatio"
#define MANIPULATOR_RED                         "Red"
#define MANIPULATOR_GREEN                       "Green"
#define MANIPULATOR_BLUE                        "Blue"
#define MANIPULATOR_BRIGHTNESS                  "Brightness"

// QRect variables ...
#define RECT_X                                  "X"
#define RECT_Y                                  "Y"
#define RECT_WIDTH                              "Width"
#define RECT_HEIGHT                             "Height"

#endif // XML_DVD_H

==> qdvdauthor_0.0.10.orig.tar.gz: qdvdauthor-0.0.10/qdvdauthor/xml_dvd.h <==
/////////////////
// Hey
////////////////
#ifndef XML_DVD_H
#define XML_DVD_H

// Here is the doc type for the QDVDAuthor application.
#define XML_DOCTYPE "QDVDAuthor"
#define DVD_PROJECT "QDVDProject"

#define THE_PROJECT_NAME "ProjectName"

// The following version number is used for the xml - ProjectFile
#define QDVDAUTHOR_VERSION		"XMLVersion"
#define QDVDAUTHOR_VERSION_NUMBER	"0.0.9"

// Here we goof around with the Templates
// Nodes
#define TEMPLATE_DOCTYPE                       "QDVDAuthor"
#define XML_TEMPLATE                           "QDVDTemplate"
#define TEMPLATE_DATA                          "DVDTemplateData"
#define TEMPLATE_DESCRIPTION                   "TemplateDescription"
#define TEMPLATE_DROPZONE                      "DropZone"
// Tags
#define TEMPLATE_NAME                          "TemplateName"
#define TEMPLATE_DROPZONE_X                    "X"
#define TEMPLATE_DROPZONE_Y                    "Y"
#define TEMPLATE_DROPZONE_WIDTH                "Width"
#define TEMPLATE_DROPZONE_HEIGHT               "Height"
#define TEMPLATE_DROPZONE_NUMBER               "Number"

// Here are the defines for qdvdauthor.
#define DVDAUTHOR                               "DVDAuthor"
#define DVDAUTHOR_TEMP_PATH                     "TempPath"
#define DVDAUTHOR_PROJECT_PATH                  "ProjectPath"
#define DVDAUTHOR_CURRENT_PATH                  "CurrentPath"
#define DVDAUTHOR_ROOT_VMGM                     "MainVMGM"
#define DVDAUTHOR_ROOT_MENU                     "DVDMenu"
#define DVDAUTHOR_MENU                          "MenuVariables"
#define DVDAUTHOR_PREVIEW                       "PreviewVariables"

// Here are the defines for teh DVDMenu - Interface.
//#define DVD_MENU                                "DVDMenu"
#define MENU_NAME                               "MenuName"
#define MENU_SOUND                              "MenuSound"
#define MENU_MOVIE                              "MenuMovie"
#define MENU_BACKGROUND                         "MenuBackround"
#define MENU_OFFSET                             "MenuOffset"
#define MENU_DURATION                           "MenuDuration"
#define MENU_ANIMATION                          "MenuAnimation"
#define MENU_HIGHLIGHTED_MASK                   "MenuHighlightedMask"
#define MENU_SELECTED_MASK                      "MenuSelectedMask"
#define MENU_MASK_COLORS                        "MaskColors"
#define MENU_RESIZE_ALGO                        "ResizeAlgo"
#define MENU_STRETCH_TYPE                       "StretchType"
#define MENU_OFFSET_X                           "OffsetX"
#define MENU_OFFSET_Y                           "OffsetY"
#define MENU_FORMAT                             "MenuFormat"
#define MENU_WIDTH                              "MenuWidth"
#define MENU_HEIGHT                             "MenuHeight"

// This one is used for Templates. If nothing has been put into a DropZone, ignore.
#define IGNORE_OBJECT                            "IgnoreObject"

#define ANIMATION_OBJECT                        "AnimationObject"

// Here are the defines for the MenuObject derived classes ...
#define MENU_OBJECT                             "MenuObject"
//#define MENU_OBJECT_FRAME                       "FrameObject"
#define MENU_OBJECT_TEXT                        "TextObject"
#define MENU_OBJECT_IMAGE                       "ImageObject"
#define MENU_OBJECT_MOVIE                       "MovieObject"
#define MENU_OBJECT_BUTTON                      "ButtonObject"
#define MENU_OBJECT_COLLECTION                  "ObjectCollection"

// The MenuObject Variables ...
#define MENU_OBJECT_NAME                        "ObjectName"
#define MENU_OBJECT_EXTRACTION_PATH             "ObjectExtractionPath"

// The FrameObject - class
#define FRAME_OBJECT                            "FrameObject"
#define FRAME_OBJECT_COLOR                      "Color"
#define FRAME_OBJECT_WIDTH                      "Width"
#define FRAME_OBJECT_STYLE                      "Style"
#define FRAME_OBJECT_JOIN                       "Join"

// The TextObject - class
#define TEXT_OBJECT                             "TextObject"
#define TEXT_OBJECT_TEXT                        "Text"
#define TEXT_OBJECT_TEXT_ALIGN                  "TextAlign"
#define TEXT_OBJECT_FONT                        "Font"
#define TEXT_OBJECT_BACKGROUND_COLOR            "BackgroundColor"
#define TEXT_OBJECT_FOREGROUND_COLOR            "ForegroundColor"

// The ImageObject - class
#define IMAGE_OBJECT                            "ImageObject"
#define IMAGE_OBJECT_FILE_NAME                  "FileName"

// The MovieObject - class
#define MOVIE_OBJECT                            "MovieObject"
#define MOVIE_OBJECT_FILE_NAME                  "FileName"
#define MOVIE_OBJECT_OFFSET                     "Offset"
#define MOVIE_OBJECT_DURATION                   "Duration"
#define MOVIE_OBJECT_SIZE                       "Size"

// The ObjectCollection - class
#define OBJECT_COLLECTION                       "ObjectCollection"

#define BUTTON_OBJECT                           "ButtonObject"
#define BUTTON_OBJECT_NAME                      "ButtonName"
#define BUTTON_OBJECT_NORMAL                    "NormalState"
#define BUTTON_OBJECT_SELECTED                  "SelectedState"
#define BUTTON_OBJECT_HIGHLIGHTED               "HighlightedState"
#define BUTTON_OBJECT_ACTION                    "Action"
#define BUTTON_OBJECT_UP                        "Up"
#define BUTTON_OBJECT_DOWN                      "Down"
#define BUTTON_OBJECT_LEFT                      "Left"
#define BUTTON_OBJECT_RIGHT                     "Right"
#define BUTTON_OBJECT_SOURCE_ENTRY              "SourceEntry"
#define BUTTON_OBJECT_MOVEABLE                  "Moveable"

// The SourceFileEntry - class
#define SOURCE_OBJECT                           "SourceEntry"
#define SOURCE_OBJECT_DISPLAY_NAME              "DisplayName"
#define SOURCE_OBJECT_IS_SOUND_SOURCE           "SoundSource"
#define SOURCE_OBJECT_INFO                      "SourceInfo"
#define SOURCE_OBJECT_FILE_NAME                 "File"
#define SOURCE_OBJECT_CHAPTERS                  "Chapters"
#define SOURCE_OBJECT_SIZE                      "Size"
#define SOURCE_OBJECT_RESOLUTION                "Resolution"
#define SOURCE_OBJECT_FPS                       "FPS"
#define SOURCE_OBJECT_RATIO                     "Ratio"
#define SOURCE_OBJECT_LENGTH                    "Length"
#define SOURCE_OBJECT_FORMAT                    "Format"
#define SOURCE_OBJECT_STATUS                    "Status"
#define SOURCE_OBJECT_BITS                      "Bits"
#define SOURCE_OBJECT_SAMPLE                    "Sample"
#define SOURCE_OBJECT_BPS                       "BPS"
#define SOURCE_OBJECT_PROPERTIES                "Properties"
#define SOURCE_OBJECT_TRANSCODE                 "TranscodeInterface"

#define SOURCE_PROPERTIES_POST                  "PostCommands"
#define SOURCE_PROPERTIES_PRE                   "PreCommands"
#define SOURCE_PROPERTIES_PAUSE                 "Pause"

#define TRANSCODE_VIDEO_FORMAT                  "VideoFormat"
#define TRANSCODE_VIDEO_TYPE                    "VideoType"
#define TRANSCODE_RESOLUTION                    "Resolution"
#define TRANSCODE_VIDEO_BITRATE                 "VideoBitrate"
#define TRANSCODE_FRAME_RATE                    "FrameRate"
#define TRANSCODE_RATIO                         "Ratio"
#define TRANSCODE_AUDIO_FORMAT                  "AudioFormat"
#define TRANSCODE_AUDIO_TYPE                    "AudioType"
#define TRANSCODE_AUDIO_BITRATE                 "AudioBitrate"
#define TRANSCODE_SAMPLE_RATE                   "SampleRate"
#define TRANSCODE_STARTING_AT                   "StartingAt"
#define TRANSCODE_ENDING_AT                     "EndingAt"

// The Modifier - class - variables :
#define MODIFIERS                               "Modifiers"
#define MODIFIERS_ROTATE                        "Rotate"
#define MODIFIERS_ZOOM                          "Zoom"
#define MODIFIERS_SCALEX                        "ScaleX"
#define MODIFIERS_SCALEY                        "ScaleY"
#define MODIFIERS_SHEARX                        "ShearX"
#define MODIFIERS_SHEARY                        "ShearY"
#define MODIFIERS_TRANSPARENCY                  "Transparency"

// The ImageManipulator - class
#define MANIPULATOR                             "Manipulator"
#define MANIPULATOR_FILE_NAME                   "FileName"
#define MANIPULATOR_SHOW_BACKGROUND             "ShowBackground"
#define MANIPULATOR_STARTX                      "StartX"
#define MANIPULATOR_STARTY                      "StartY"
#define MANIPULATOR_XRES                        "XRes"
#define MANIPULATOR_YRES                        "YRes"
#define MANIPULATOR_TRANSFORMATION_MODE	        "TransformationMode"
#define MANIPULATOR_ASPECT_RATIO                "AspectRatio"
#define MANIPULATOR_RED                         "Red"
#define MANIPULATOR_GREEN                       "Green"
#define MANIPULATOR_BLUE                        "Blue"
#define MANIPULATOR_BRIGHTNESS                  "Brightness"

// QRect variables ...
#define RECT_X                                  "X"
#define RECT_Y                                  "Y"
#define RECT_WIDTH                              "Width"
#define RECT_HEIGHT                             "Height"

#endif // XML_DVD_H
